package jp.agentec.sinaburocast.common.interceptor;

import javax.servlet.http.HttpServletResponse;

import jp.agentec.sinaburocast.common.SinaburoConstant;
import jp.agentec.sinaburocast.common.annotation.NoLogin;
import jp.agentec.sinaburocast.common.util.PropertyUtil;
import jp.agentec.sinaburocast.common.util.ServletUtil;
import jp.agentec.sinaburocast.common.util.SinaburoUtil;
import jp.agentec.sinaburocast.vo.AuthenticatedTokenVO;

import org.aopalliance.intercept.MethodInvocation;
import org.seasar.framework.aop.interceptors.AbstractInterceptor;
import org.seasar.framework.log.Logger;
import org.seasar.struts.util.RequestUtil;
import org.seasar.struts.util.ResponseUtil;

/**
 * AdminLoginCheckInterceptorクラス<br>
 * 認証が必要なページで認証してない場合をログイン画面へ遷移する。
 *
 * @author choi-c
 *
 */
public class AdminLoginCheckInterceptor extends AbstractInterceptor {
    private static final long serialVersionUID = -9197894563727449743L;
    private static final Logger LOGGER = Logger.getLogger(AdminLoginCheckInterceptor.class);

	public AdminLoginCheckInterceptor() {
	}

	@Override
    public Object invoke(final MethodInvocation invocation) throws Throwable {
    	
    	String className = getTargetClass(invocation).getName();
    	String ipAddress = ServletUtil.getRemoteAddr(RequestUtil.getRequest());
    	
    	AuthenticatedTokenVO token = (AuthenticatedTokenVO) RequestUtil.getRequest().getSession().getAttribute(SinaburoConstant.AttrKey.AUTHENTICATED_TOKEN);
    	if(className.startsWith("jp.agentec.sinaburocast.action.admin.")) { // 管理画面
    		if (!SinaburoUtil.isAllowedSrc(ipAddress, PropertyUtil.getList("ADMIN_ALLOWED_SRC"))) { // IPチェック
				LOGGER.info("Illegal Access to " + className + " from " + ipAddress);
				ResponseUtil.getResponse().sendError(HttpServletResponse.SC_FORBIDDEN);
    			return null;
    		}
    		if (!className.equals("jp.agentec.sinaburocast.action.admin.LoginAction") && (token == null || token.adminUser == null)) { // 認証チェック
    			ResponseUtil.getResponse().sendRedirect("/em/admin/login/");
    			return null;
    		}
    	}
    	else if (className.startsWith("jp.agentec.sinaburocast.action.user.")) { // 利用者画面
    	    @SuppressWarnings("unchecked")
    		boolean noLogin = invocation.getMethod().getAnnotation(NoLogin.class) != null || getTargetClass(invocation).getAnnotation(NoLogin.class) != null;
    		if (!noLogin && (token == null || token.member == null)) { // 認証チェック
    			ResponseUtil.getResponse().sendRedirect("/em/user/login/");
    			return null;
    		}
    	}
    	else if (className.startsWith("jp.agentec.sinaburocast.action.batch.")) { // バッチ処理
			if (!SinaburoUtil.isAllowedSrc(ipAddress, PropertyUtil.getList("BATCH_ALLOWED_SRC"))) { // IPチェック
				LOGGER.info("Illegal Access to " + className + " from " + ipAddress);
				ResponseUtil.getResponse().sendError(HttpServletResponse.SC_FORBIDDEN);
				return null;
			}
    	}
    	
        return invocation.proceed();
    	
    }	
}
