package jp.agentec.sinaburocast.common.interceptor;

import jp.agentec.sinaburocast.common.SinaburoConstant;
import jp.agentec.sinaburocast.common.annotation.OperationHistoryAno;
import jp.agentec.sinaburocast.entity.AdminUser;
import jp.agentec.sinaburocast.entity.OperationHistory;
import jp.agentec.sinaburocast.service.OperationHistoryService;
import jp.agentec.sinaburocast.vo.AuthenticatedTokenVO;

import org.aopalliance.intercept.MethodInvocation;
import org.seasar.framework.aop.interceptors.AbstractInterceptor;
import org.seasar.framework.log.Logger;
import org.seasar.framework.util.StringUtil;
import org.seasar.struts.util.RequestUtil;

/**
 * Argument Interceptorクラス<br>
 * 引数がnullの場合例外をスローする
 *
 * @author choi-c
 *
 */
public class OperationHistoryAnoInterceptor extends AbstractInterceptor {
	private static final long serialVersionUID = -510580990235903191L;

    private static final Logger logger = Logger.getLogger(TraceInterceptor.class);
    //private static final Class[] wrapperClasses = new Class[]{Byte.class, Short.class, Integer.class, Long.class, Character.class, Float.class, Double.class, Boolean.class};

    public OperationHistoryService operationHistoryService;
    
    /**
     * OperationHistoryAnoアノテーションを付与したメソッドに対して操作履歴を登録する。
     */
    @Override
    public Object invoke(final MethodInvocation invocation) throws Throwable {
    	String eventKey=getTargetClass(invocation).getName() + "." + invocation.getMethod().getName();
    	
    	OperationHistoryAno anotation = invocation.getMethod().getAnnotation(OperationHistoryAno.class);
    	
    	
    	AdminUser admin = null;
    	//ログアウトの場合
    	if(StringUtil.equals("jp.agentec.sinaburocast.action.admin.LoginAction.logout", eventKey)){
    		admin = getAdmin();
    	}
    	
   	    Object result = invocation.proceed();
		
        if(admin == null){
        	admin = getAdmin();
        	if(admin == null){
        		return result;
        	}
        }
        Object obj = RequestUtil.getRequest().getAttribute(SinaburoConstant.notRegistOperationHistoryKey.notRegist);
        if(result != null && result.toString().endsWith("/doubleAction.html") || (obj != null && StringUtil.equals(obj.toString(), SinaburoConstant.notRegistOperationHistoryKey.notRegist))){
        	return result;
        }
        OperationHistory operationHistory = new OperationHistory();
        operationHistory.adminUserId = admin.adminUserId;
        operationHistory.detail = anotation.detail();
        operationHistory.operationTypeId = anotation.operationTypeId();
        operationHistory.target = anotation.target();
        operationHistory.screenId = anotation.screenId();
        
        operationHistoryService.insertOperationHistory(operationHistory, admin.loginId);
        
        return result;
    }
	
	private AdminUser getAdmin(){
		Object obj = null;
		
		try {
			obj=RequestUtil.getRequest().getSession().getAttribute(SinaburoConstant.AttrKey.AUTHENTICATED_TOKEN);
		} catch (Exception e) {
			return null;// 再起動した場合エラーが発生
		}
		if(obj != null){		
			return ((AuthenticatedTokenVO)obj).adminUser;
		}
		return null;
		
	}
	
	
		  


}
